"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RNLeaflet = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _reactNativeWebview = _interopRequireDefault(require("react-native-webview"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
/* eslint-disable react/display-name */

const RNLeaflet = /*#__PURE__*/(0, _react.forwardRef)((_ref,
// eslint-disable-next-line prettier/prettier
passRef) => {
  let {
    mapLayers,
    geoJson,
    zoom = 0,
    minZoom,
    maxZoom,
    markers,
    flyTo,
    onMessage,
    onError,
    onLoadStart,
    startInLoadingState = true,
    backgroundColor,
    injectJavascript
  } = _ref;
  const htmlFile = _reactNative.Platform.OS === 'android' ? {
    uri: 'file:///android_asset/Leaflet.html'
  } : require('../html/Leaflet.html');
  const ref = (0, _react.useRef)(null);
  const [configured, setConfigured] = (0, _react.useState)(false);
  (0, _react.useImperativeHandle)(passRef, () => ({
    flyTo(_ref2) {
      let {
        latLng,
        zoom: flyToZoom
      } = _ref2;
      sendAction({
        flyTo: {
          latLng: latLng,
          zoom: flyToZoom
        }
      });
    },
    clearMarkers: () => {
      sendAction({
        clearMarkers: true
      });
    }
  }));
  const sendAction = (0, _react.useCallback)(message => {
    if (!(ref !== null && ref !== void 0 && ref.current)) {
      return;
    }
    ref.current.postMessage(`${JSON.stringify(message)}`);
  }, []);
  const injectScript = (0, _react.useCallback)(script => {
    var _ref$current;
    (_ref$current = ref.current) === null || _ref$current === void 0 ? void 0 : _ref$current.injectJavaScript(script);
  }, []);
  (0, _react.useLayoutEffect)(() => {
    if (!configured) {
      return;
    }
    if (!flyTo) {
      sendAction({
        zoom
      });
    }
    if (maxZoom) {
      sendAction({
        maxZoom
      });
    }
    if (minZoom) {
      sendAction({
        minZoom
      });
    }
    if (markers) {
      sendAction({
        markers
      });
    }
    if (geoJson) {
      sendAction({
        geoJson
      });
    }
    if (flyTo) {
      sendAction({
        flyTo: {
          latLng: flyTo === null || flyTo === void 0 ? void 0 : flyTo.latLng,
          zoom: flyTo === null || flyTo === void 0 ? void 0 : flyTo.zoom
        }
      });
    }
    if (mapLayers) {
      sendAction({
        mapLayers
      });
    }
  }, [flyTo, flyTo === null || flyTo === void 0 ? void 0 : flyTo.latLng, flyTo === null || flyTo === void 0 ? void 0 : flyTo.zoom, markers, maxZoom, sendAction, mapLayers, zoom, configured, minZoom, geoJson]);
  (0, _react.useLayoutEffect)(() => {
    if (!configured) {
      return;
    }
    if (injectJavascript) {
      injectScript(injectJavascript);
    }
  }, [configured, injectJavascript, injectScript]);
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.wrapper, {
      backgroundColor
    }]
  }, /*#__PURE__*/_react.default.createElement(_reactNativeWebview.default, {
    ref: ref,
    source: htmlFile,
    style: styles.flexer,
    containerStyle: styles.flexer,
    onMessage: e => {
      var _e$nativeEvent;
      return onMessage && onMessage(e === null || e === void 0 ? void 0 : (_e$nativeEvent = e.nativeEvent) === null || _e$nativeEvent === void 0 ? void 0 : _e$nativeEvent.data);
    },
    onError: onError,
    onLoadStart: onLoadStart,
    onLoadEnd: () => setConfigured(true),
    startInLoadingState: startInLoadingState,
    originWhitelist: ['*'],
    javaScriptEnabled: true,
    domStorageEnabled: true
  }));
});
exports.RNLeaflet = RNLeaflet;
const styles = _reactNative.StyleSheet.create({
  wrapper: {
    flex: 1
  },
  flexer: {
    flex: 1,
    backgroundColor: 'transparent'
  }
});
//# sourceMappingURL=index.js.map