/* eslint-disable react/display-name */
import React, { forwardRef, useCallback, useImperativeHandle, useLayoutEffect, useRef, useState } from 'react';
import { Platform, StyleSheet, View } from 'react-native';
import WebView from 'react-native-webview';
export const RNLeaflet = /*#__PURE__*/forwardRef((_ref,
// eslint-disable-next-line prettier/prettier
passRef) => {
  let {
    mapLayers,
    geoJson,
    zoom = 0,
    minZoom,
    maxZoom,
    markers,
    flyTo,
    onMessage,
    onError,
    onLoadStart,
    startInLoadingState = true,
    backgroundColor,
    injectJavascript
  } = _ref;
  const htmlFile = Platform.OS === 'android' ? {
    uri: 'file:///android_asset/Leaflet.html'
  } : require('../html/Leaflet.html');
  const ref = useRef(null);
  const [configured, setConfigured] = useState(false);
  useImperativeHandle(passRef, () => ({
    flyTo(_ref2) {
      let {
        latLng,
        zoom: flyToZoom
      } = _ref2;
      sendAction({
        flyTo: {
          latLng: latLng,
          zoom: flyToZoom
        }
      });
    },
    clearMarkers: () => {
      sendAction({
        clearMarkers: true
      });
    }
  }));
  const sendAction = useCallback(message => {
    if (!(ref !== null && ref !== void 0 && ref.current)) {
      return;
    }
    ref.current.postMessage(`${JSON.stringify(message)}`);
  }, []);
  const injectScript = useCallback(script => {
    var _ref$current;
    (_ref$current = ref.current) === null || _ref$current === void 0 ? void 0 : _ref$current.injectJavaScript(script);
  }, []);
  useLayoutEffect(() => {
    if (!configured) {
      return;
    }
    if (!flyTo) {
      sendAction({
        zoom
      });
    }
    if (maxZoom) {
      sendAction({
        maxZoom
      });
    }
    if (minZoom) {
      sendAction({
        minZoom
      });
    }
    if (markers) {
      sendAction({
        markers
      });
    }
    if (geoJson) {
      sendAction({
        geoJson
      });
    }
    if (flyTo) {
      sendAction({
        flyTo: {
          latLng: flyTo === null || flyTo === void 0 ? void 0 : flyTo.latLng,
          zoom: flyTo === null || flyTo === void 0 ? void 0 : flyTo.zoom
        }
      });
    }
    if (mapLayers) {
      sendAction({
        mapLayers
      });
    }
  }, [flyTo, flyTo === null || flyTo === void 0 ? void 0 : flyTo.latLng, flyTo === null || flyTo === void 0 ? void 0 : flyTo.zoom, markers, maxZoom, sendAction, mapLayers, zoom, configured, minZoom, geoJson]);
  useLayoutEffect(() => {
    if (!configured) {
      return;
    }
    if (injectJavascript) {
      injectScript(injectJavascript);
    }
  }, [configured, injectJavascript, injectScript]);
  return /*#__PURE__*/React.createElement(View, {
    style: [styles.wrapper, {
      backgroundColor
    }]
  }, /*#__PURE__*/React.createElement(WebView, {
    ref: ref,
    source: htmlFile,
    style: styles.flexer,
    containerStyle: styles.flexer,
    onMessage: e => {
      var _e$nativeEvent;
      return onMessage && onMessage(e === null || e === void 0 ? void 0 : (_e$nativeEvent = e.nativeEvent) === null || _e$nativeEvent === void 0 ? void 0 : _e$nativeEvent.data);
    },
    onError: onError,
    onLoadStart: onLoadStart,
    onLoadEnd: () => setConfigured(true),
    startInLoadingState: startInLoadingState,
    originWhitelist: ['*'],
    javaScriptEnabled: true,
    domStorageEnabled: true
  }));
});
const styles = StyleSheet.create({
  wrapper: {
    flex: 1
  },
  flexer: {
    flex: 1,
    backgroundColor: 'transparent'
  }
});
//# sourceMappingURL=index.js.map